==> scanbot_sdk-2.10.0.tar.gz: lib/json/common_data.dart <==
import 'dart:math';

import 'package:flutter/material.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

part 'common_data.g.dart';

///Available image filters
enum ImageFilterType {
  NONE,
  COLOR_ENHANCED,
  GRAYSCALE,
  BINARIZED,
  COLOR_DOCUMENT,
  PURE_BINARIZED,
  BACKGROUND_CLEAN,
  BLACK_AND_WHITE,
  OTSU_BINARIZATION,
  DEEP_BINARIZATION,
  EDGE_HIGHLIGHT,
  LOW_LIGHT_BINARIZATION,
  LOW_LIGHT_BINARIZATION_2
}

///Document detection status
enum DetectionStatus {
  OK,
  OK_BUT_TOO_SMALL,
  OK_BUT_BAD_ANGLES,
  OK_BUT_BAD_ASPECT_RATIO,
  OK_OFF_CENTER,
  OK_BARCODE,
  ERROR_NOTHING_DETECTED,
  ERROR_TOO_DARK,
  ERROR_TOO_NOISY
}

/// Applied interface orientation
enum OrientationLockMode {
  /// Do not restrict interface orientation */
  NONE,

  /// Portrait screen orientations only */
  PORTRAIT,

  /// Landscape screen orientations only */
  LANDSCAPE,
}

enum ImageFormat { JPG, PNG }

enum CameraModule { FRONT, BACK }

///Standart result status
enum OperationResult { SUCCESS, ERROR, CANCELED }

///Camera view  fill screen modes
enum CameraPreviewMode { FIT_IN, FILL_IN }

///Parent result class for ready to use components return data
class Result {
  ///Standart result status
  @JsonKey(ignore: true)
  OperationResult? operationResult = OperationResult.SUCCESS;

  ///Message with description of returned result, for example, error message
  String? message;

  Result();
}

@JsonSerializable(includeIfNull: false)
class Size {
  int width;

  int height;

  Size(this.width, this.height);

  factory Size.fromJson(Map<String, dynamic> json) => _$SizeFromJson(json);

  Map<String, dynamic> toJson() => _$SizeToJson(this);
}

@JsonSerializable(includeIfNull: false)
class Rect {
  double? width;
  double? height;

  double? x;
  double? y;

  Rect(this.x, this.y, this.width, this.height);

  factory Rect.fromJson(Map<String, dynamic> json) => _$RectFromJson(json);

  Map<String, dynamic> toJson() => _$RectToJson(this);
}

@JsonSerializable(includeIfNull: false)
class PolygonPoint extends Point {
  PolygonPoint(num x, num y) : super(x, y);

  factory PolygonPoint.fromJson(Map<String, dynamic> json) =>
      _$PolygonPointFromJson(json);

  Map<String, dynamic> toJson() => _$PolygonPointToJson(this);
}

@JsonSerializable(includeIfNull: false)
class ZoomRange {
  double minZoom;
  double maxZoom;
  ZoomRange(this.minZoom, this.maxZoom);

  factory ZoomRange.fromJson(Map<String, dynamic> json) =>
      _$ZoomRangeFromJson(json);

  Map<String, dynamic> toJson() => _$ZoomRangeToJson(this);
}

/// The Scanbot SDK provides a ready-to-use UI for document scanning and cropping.
///Both components use the notion of a 'page' as a data model for the scanning and cropping activities.
@JsonSerializable(includeIfNull: false, explicitToJson: true)
class Page {
  /// The detection result of the document detection operation that produced the page (either the document scanner or detectDocument()).
  DetectionStatus? detectionStatus;

  ///Limits the maximum resolution (width, height) of the document image. If null is passed, this property is effectively ignored. If specified, width and height must be > 0.
  Size? documentImageSizeLimit;

  /// The image filter which was applied to the document image of this page.
  ImageFilterType? filter;

  ///A string identifying the page in the internal page file storage
  String pageId;

  /// The page's cropping polygon as calculated by a document detection operation or as set by the cropping UI. Modifying the polygon will change the polygon as shown in the cropping UI but will not automatically re-crop the original image.
  List<PolygonPoint>? polygon;

  ///File URI of the original image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? originalImageFileUri;

  ///File URI of the cropped document image (if document detection was successful)
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? documentImageFileUri;

  ///File URI of a screen-sized preview of the original image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? originalPreviewImageFileUri;

  ///File URI of a screen-sized preview of the document image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? documentPreviewImageFileUri;

  Page(this.pageId,
      {this.detectionStatus,
      this.documentImageSizeLimit,
      this.filter,
      this.polygon,
      this.originalImageFileUri,
      this.documentImageFileUri,
      this.originalPreviewImageFileUri,
      this.documentPreviewImageFileUri});

  factory Page.fromJson(Map<String, dynamic> json) => _$PageFromJson(json);

  Map<String, dynamic> toJson() => _$PageToJson(this);
}

@JsonSerializable(includeIfNull: false, explicitToJson: true)
class FinderAspectRatio {
  final double height;

  final double width;

  const FinderAspectRatio({this.width = 0, this.height = 0});

  factory FinderAspectRatio.fromJson(Map<String, dynamic> json) =>
      _$FinderAspectRatioFromJson(json);

  Map<String, dynamic> toJson() => _$FinderAspectRatioToJson(this);
}

///Available engine modes for barcode V3 scanner version
enum EngineMode { Legacy, NextGen }

enum MSIPlesseyChecksumAlgorithm {
  None,
  Mod10,
  Mod11IBM,
  Mod11NCR,
  Mod1010,
  Mod1110IBM,
  Mod1110NCR
}

enum BarcodeImageGenerationType { NONE, VIDEO_FRAME, CAPTURED_IMAGE }

/// The amount of barcodes on one frame that can be scannet at once. Note that this option directly affect performance
/// Low <= 7
/// Hight <= 30
enum CodeDensity { LOW, HIGH }

@JsonSerializable(includeIfNull: false, explicitToJson: true)
class FinderInsets {
  /// Pixel for the finder window from the left.
  final double? left;

  /// Pixel for the finder window from the top.
  final double? top;

  /// Pixel for the finder window from the bottom.
  final double? bottom;

  /// Pixel for the finder window from the right.
  final double? right;

  const FinderInsets({this.left, this.top, this.bottom, this.right});

  factory FinderInsets.fromJson(Map<String, dynamic> json) =>
      _$FinderInsetsFromJson(json);

  Map<String, dynamic> toJson() => _$FinderInsetsToJson(this);
}

/// Barcode document format
enum BarcodeDocumentFormat {
  /// American Association of Motor Vehicle Administrators barcode document */
  AAMVA,

  /// Boarding pass barcode document */
  BOARDING_PASS,

  /// German medical plan barcode document */
  DE_MEDICAL_PLAN,

  /// German medical certificate barcode document */
  MEDICAL_CERTIFICATE,

  /// ID Card barcode document */
  ID_CARD_PDF_417,

  /// SEPA barcode document */
  SEPA,

  /// Swiss QR barcode document */
  SWISS_QR,

  /// VCard barcode document */
  VCARD,

  /// GS1 barcode document */
  GS1,
}

/// Barcode document format */
enum BarcodeFormat {
  /// Aztec barcode type */
  AZTEC,

  /// CODABAR barcode type */
  CODABAR,

  /// CODE_39 barcode type */
  CODE_39,

  /// CODE_93 barcode type */
  CODE_93,

  /// CODE_128 barcode type */
  CODE_128,

  /// DATA_MATRIX barcode type */
  DATA_MATRIX,

  /// EAN_8 barcode type */
  EAN_8,

  /// EAN_13 barcode type */
  EAN_13,

  /// ITF barcode type */
  ITF,

  /// PDF_417 barcode type */
  PDF_417,

  /// QR_CODE barcode type */
  QR_CODE,

  /// RSS_14 barcode type */
  RSS_14,

  /// RSS_EXPANDED barcode type */
  RSS_EXPANDED,

  /// UPC_A barcode type */
  UPC_A,

  /// UPC_E barcode type */
  UPC_E,

  /// Unknown barcode type */
  UNKNOWN,

  /// MSI Plessey barcode type */
  MSI_PLESSEY,
}

/// Barcode scanner engine mode
enum BarcodeOverlayTextFormat {
  /// Show only barcode overlay frame. */
  NONE,

  /// Show barcode value with extention. */
  CODE,

  /// Show barcode value with barcode format. */
  CODE_AND_TYPE,
}

/// Barcode Selection Overlay configuration
@JsonSerializable(
  includeIfNull: false,
)
class SelectionOverlayConfiguration {
  /// Whether the barcode selection overlay is enabled or not.
  bool overlayEnabled;

  /// Define the way of how to show barcode data with selection overlay.
  BarcodeOverlayTextFormat textFormat;

  /// The color of the polygon in the selection overlay.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? polygonColor = Colors.white;

  /// The color of the text in the selection overlay.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? textColor = Colors.black;

  /// The color of the texts background in the selection overlay.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? textContainerColor = Colors.white;

  /// The color of the polygon in the selection overlay, when highlighted.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? highlightedPolygonColor = Colors.black;

  /// The color of the text in the selection overlay, when highlighted.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? highlightedTextColor = Colors.white;

  /// The color of the texts background in the selection overlay, when highlighted.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? highlightedTextContainerColor = Colors.black;

  SelectionOverlayConfiguration(
    this.overlayEnabled,
    this.textFormat,
    this.polygonColor,
    this.textColor,
    this.textContainerColor,
    this.highlightedPolygonColor,
    this.highlightedTextColor,
    this.highlightedTextContainerColor,
  );

  Map<String, dynamic> toJson() => _$SelectionOverlayConfigurationToJson(this);
}

==> scanbot_sdk-2.12.1.tar.gz: lib/json/common_data.dart <==
import 'dart:math';

import 'package:flutter/material.dart';
import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

part 'common_data.g.dart';

///Available image filters
enum ImageFilterType {
  NONE,
  COLOR_ENHANCED,
  GRAYSCALE,
  BINARIZED,
  COLOR_DOCUMENT,
  PURE_BINARIZED,
  BACKGROUND_CLEAN,
  BLACK_AND_WHITE,
  OTSU_BINARIZATION,
  DEEP_BINARIZATION,
  EDGE_HIGHLIGHT,
  LOW_LIGHT_BINARIZATION,
  LOW_LIGHT_BINARIZATION_2
}

///Document detection status
enum DetectionStatus {
  OK,
  OK_BUT_TOO_SMALL,
  OK_BUT_BAD_ANGLES,
  OK_BUT_BAD_ASPECT_RATIO,
  OK_OFF_CENTER,
  OK_BARCODE,
  ERROR_NOTHING_DETECTED,
  ERROR_TOO_DARK,
  ERROR_TOO_NOISY
}

/// Applied interface orientation
enum OrientationLockMode {
  /// Do not restrict interface orientation */
  NONE,

  /// Portrait screen orientations only */
  PORTRAIT,

  /// Landscape screen orientations only */
  LANDSCAPE,
}

enum ImageFormat { JPG, PNG }

enum CameraModule { FRONT, BACK }

///Standart result status
enum OperationResult { SUCCESS, ERROR, CANCELED }

///Camera view  fill screen modes
enum CameraPreviewMode { FIT_IN, FILL_IN }

///Parent result class for ready to use components return data
class Result {
  ///Standart result status
  @JsonKey(includeToJson: false, includeFromJson: false)
  OperationResult? operationResult = OperationResult.SUCCESS;

  ///Message with description of returned result, for example, error message
  String? message;

  Result();
}

@JsonSerializable(includeIfNull: false)
class Size {
  int width;

  int height;

  Size(this.width, this.height);

  factory Size.fromJson(Map<String, dynamic> json) => _$SizeFromJson(json);

  Map<String, dynamic> toJson() => _$SizeToJson(this);
}

@JsonSerializable(includeIfNull: false)
class Rect {
  double? width;
  double? height;

  double? x;
  double? y;

  Rect(this.x, this.y, this.width, this.height);

  factory Rect.fromJson(Map<String, dynamic> json) => _$RectFromJson(json);

  Map<String, dynamic> toJson() => _$RectToJson(this);
}

@JsonSerializable(includeIfNull: false)
class PolygonPoint extends Point {
  PolygonPoint(num x, num y) : super(x, y);

  factory PolygonPoint.fromJson(Map<String, dynamic> json) =>
      _$PolygonPointFromJson(json);

  Map<String, dynamic> toJson() => _$PolygonPointToJson(this);
}

@JsonSerializable(includeIfNull: false)
class ZoomRange {
  double minZoom;
  double maxZoom;

  ZoomRange(this.minZoom, this.maxZoom);

  factory ZoomRange.fromJson(Map<String, dynamic> json) =>
      _$ZoomRangeFromJson(json);

  Map<String, dynamic> toJson() => _$ZoomRangeToJson(this);
}

/// The Scanbot SDK provides a ready-to-use UI for document scanning and cropping.
///Both components use the notion of a 'page' as a data model for the scanning and cropping activities.
@JsonSerializable(includeIfNull: false, explicitToJson: true)
class Page {
  /// The detection result of the document detection operation that produced the page (either the document scanner or detectDocument()).
  DetectionStatus? detectionStatus;

  ///Limits the maximum resolution (width, height) of the document image. If null is passed, this property is effectively ignored. If specified, width and height must be > 0.
  Size? documentImageSizeLimit;

  /// The image filter which was applied to the document image of this page.
  ImageFilterType? filter;

  ///A string identifying the page in the internal page file storage
  String pageId;

  /// The page's cropping polygon as calculated by a document detection operation or as set by the cropping UI. Modifying the polygon will change the polygon as shown in the cropping UI but will not automatically re-crop the original image.
  List<PolygonPoint>? polygon;

  ///File URI of the original image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? originalImageFileUri;

  ///File URI of the cropped document image (if document detection was successful)
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? documentImageFileUri;

  ///File URI of a screen-sized preview of the original image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? originalPreviewImageFileUri;

  ///File URI of a screen-sized preview of the document image
  @JsonKey(toJson: fileUriToString, fromJson: stringToFileUri)
  Uri? documentPreviewImageFileUri;

  Page(this.pageId,
      {this.detectionStatus,
      this.documentImageSizeLimit,
      this.filter,
      this.polygon,
      this.originalImageFileUri,
      this.documentImageFileUri,
      this.originalPreviewImageFileUri,
      this.documentPreviewImageFileUri});

  factory Page.fromJson(Map<String, dynamic> json) => _$PageFromJson(json);

  Map<String, dynamic> toJson() => _$PageToJson(this);
}

@JsonSerializable(includeIfNull: false, explicitToJson: true)
class FinderAspectRatio {
  final double height;

  final double width;

  const FinderAspectRatio({this.width = 0, this.height = 0});

  factory FinderAspectRatio.fromJson(Map<String, dynamic> json) =>
      _$FinderAspectRatioFromJson(json);

  Map<String, dynamic> toJson() => _$FinderAspectRatioToJson(this);
}

///Available engine modes for barcode V3 scanner version
enum EngineMode { Legacy, NextGen }

enum MSIPlesseyChecksumAlgorithm {
  None,
  Mod10,
  Mod11IBM,
  Mod11NCR,
  Mod1010,
  Mod1110IBM,
  Mod1110NCR
}

enum BarcodeImageGenerationType { NONE, VIDEO_FRAME, CAPTURED_IMAGE }

/// The amount of barcodes on one frame that can be scannet at once. Note that this option directly affect performance
/// Low <= 7
/// Hight <= 30
enum CodeDensity { LOW, HIGH }

@JsonSerializable(includeIfNull: false)
class Insets {
  /// Pixel for the finder window from the left.
  final double? left;

  /// Pixel for the finder window from the top.
  final double? top;

  /// Pixel for the finder window from the bottom.
  final double? bottom;

  /// Pixel for the finder window from the right.
  final double? right;

  const Insets({this.left, this.top, this.bottom, this.right});

  factory Insets.fromJson(Map<String, dynamic> json) => _$InsetsFromJson(json);

  factory Insets.all(double all) =>
      Insets(left: all, top: all, right: all, bottom: all);

  factory Insets.vertical(double inset) =>
      Insets(left: 0, top: inset, right: 0, bottom: inset);

  factory Insets.horizontal(double inset) =>
      Insets(left: inset, top: 0, right: inset, bottom: 0);

  Map<String, dynamic> toJson() => _$InsetsToJson(this);
}

/// Barcode document format
enum BarcodeDocumentFormat {
  /// American Association of Motor Vehicle Administrators barcode document */
  AAMVA,

  /// Boarding pass barcode document */
  BOARDING_PASS,

  /// German medical plan barcode document */
  DE_MEDICAL_PLAN,

  /// German medical certificate barcode document */
  MEDICAL_CERTIFICATE,

  /// ID Card barcode document */
  ID_CARD_PDF_417,

  /// SEPA barcode document */
  SEPA,

  /// Swiss QR barcode document */
  SWISS_QR,

  /// VCard barcode document */
  VCARD,

  /// GS1 barcode document */
  GS1,
}

/// Barcode document format */
enum BarcodeFormat {
  /// Aztec barcode type */
  AZTEC,

  /// CODABAR barcode type */
  CODABAR,

  /// CODE_39 barcode type */
  CODE_39,

  /// CODE_93 barcode type */
  CODE_93,

  /// CODE_128 barcode type */
  CODE_128,

  /// DATA_MATRIX barcode type */
  DATA_MATRIX,

  /// EAN_8 barcode type */
  EAN_8,

  /// EAN_13 barcode type */
  EAN_13,

  /// ITF barcode type */
  ITF,

  /// PDF_417 barcode type */
  PDF_417,

  /// QR_CODE barcode type */
  QR_CODE,

  /// RSS_14 barcode type */
  RSS_14,

  /// RSS_EXPANDED barcode type */
  RSS_EXPANDED,

  /// UPC_A barcode type */
  UPC_A,

  /// UPC_E barcode type */
  UPC_E,

  /// Unknown barcode type */
  UNKNOWN,

  /// MSI Plessey barcode type */
  MSI_PLESSEY,

  /// IATA_2_OF_5 barcode type */
  IATA_2_OF_5,

  /// INDUSTRIAL_2_OF_5 barcode type */
  INDUSTRIAL_2_OF_5,

  /// CODE_25 barcode type */
  CODE_25
}

/// Barcode scanner engine mode
enum BarcodeOverlayTextFormat {
  /// Show only barcode overlay frame. */
  NONE,

  /// Show barcode value with extention. */
  CODE,

  /// Show barcode value with barcode format. */
  CODE_AND_TYPE,
}

/// Barcode Selection Overlay configuration
@JsonSerializable(includeIfNull: false, createFactory: false)
class SelectionOverlayConfiguration {
  /// Whether the barcode selection overlay is enabled or not.
  bool overlayEnabled;

  /// Define the way of how to show barcode data with selection overlay.
  BarcodeOverlayTextFormat textFormat;

  /// The color of the polygon in the selection overlay.
  @JsonKey(toJson: toColorString)
  Color? polygonColor = Colors.white;

  /// The color of the text in the selection overlay.
  @JsonKey(toJson: toColorString)
  Color? textColor = Colors.black;

  /// The color of the texts background in the selection overlay.
  @JsonKey(toJson: toColorString)
  Color? textContainerColor = Colors.white;

  /// The color of the polygon in the selection overlay, when highlighted.
  @JsonKey(toJson: toColorString)
  Color? highlightedPolygonColor = Colors.black;

  /// The color of the text in the selection overlay, when highlighted.
  @JsonKey(toJson: toColorString)
  Color? highlightedTextColor = Colors.white;

  /// The color of the texts background in the selection overlay, when highlighted.
  @JsonKey(toJson: toColorString)
  Color? highlightedTextContainerColor = Colors.black;

  SelectionOverlayConfiguration({
    this.overlayEnabled = true,
    this.textFormat = BarcodeOverlayTextFormat.CODE_AND_TYPE,
    this.polygonColor = Colors.white,
    this.textColor = Colors.black,
    this.textContainerColor = Colors.white,
    this.highlightedPolygonColor,
    this.highlightedTextColor,
    this.highlightedTextContainerColor,
  });

  Map<String, dynamic> toJson() => _$SelectionOverlayConfigurationToJson(this);
}
